<?php

class DistributertypeController extends Controller
{
	public function init()
	{
		parent::init();
		$this->initAjaxCsrfToken();
	}

	// this function will work to post csrf token.
	protected function initAjaxCsrfToken()
	{

		Yii::app()->clientScript->registerScript('AjaxCsrfToken', ' $.ajaxSetup({
                         data: {"' . Yii::app()->request->csrfToken . '": "' . Yii::app()->request->csrfToken . '"},
                         cache:false
                    });', CClientScript::POS_HEAD);
	}

	public function accessRules()
	{
		return array(
			array(
				'allow', // allow all users to perform 'index' and 'view' actions
				'actions' => array('login', 'error', 'logout'),
				'users' => array('*'),
			),
			array(
				'allow', // allow authenticated user to perform 'create' and 'update' actions
				'actions' => array('Index', 'Create', 'CreateHiddenGMC', 'GetList', 'Save', 'Delete', 'Savehiddengmc'),
				'expression' => '$user->isMember()',
			),
			array(
				'deny', // deny all users
				'users' => array('*'),
			),
		);
	}

	public function actionIndex()
	{

		//if (isset(Yii::app()->user->havePermissionOn['master_distributer_type_view']) || Yii::app()->user->authorised_user == 1) {
		$_GET  = filter_input_array(INPUT_GET, FILTER_SANITIZE_STRING);
		if (count($_GET) > 0) {
			$this->render('index');
		} else {
			throw new CHttpException(404, 'Page not found.');
		}
		/*} else {
			throw new CHttpException(401, 'Unauthorized Access');
		}*/
	}

	// Uncomment the following methods and override them if needed
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
		);
	}


	/**
	 * Creates a new model.
	 * If creation is successful, the browser will be redirected to the 'view' page.
	 */


	public function actionCreate()
	{
		$_GET  = filter_input_array(INPUT_GET, FILTER_SANITIZE_STRING);
		if (count($_GET) > 0) {
			$model = new MasDistributerType();
			$id = (int) Yii::app()->request->getParam('id');
			if ($id > 0) {
				$model = $model->findByPk($id);
			}
			Yii::app()->clientScript->scriptMap = array('*jquery.js' => false, '*jquery.min.js' => false, 'jquery.min.js' => false, '*jquery-ui.js' => false, '*jquery-ui.min.js' => false, 'jquery-2.1.4.js' => false);
			$this->render('create', array('model' => $model), false, false);
		} else {
			throw new CHttpException(404, 'Page not found.');
		}
	}

	public function actionCreateHiddenGMC()
	{
		$_GET  = filter_input_array(INPUT_GET, FILTER_SANITIZE_STRING);
		if (count($_GET) > 0) {
			$model = new MasDistributerType();
			$id = (int) Yii::app()->request->getParam('id');
			if ($id > 0) {
				$model = $model->findByPk($id);
				$condition = ' distributer_type_id=' . $id;
				$modelHiddenDistributerGmcs     = HiddenDistributerGmcs::model()->findAll(array('condition' => $condition));
				if (empty($modelHiddenDistributerGmcs)) {
					$modelHiddenDistributerGmcs = array(new HiddenDistributerGmcs());
				}
			}
			Yii::app()->clientScript->scriptMap = array('*jquery.js' => false, '*jquery.min.js' => false, 'jquery.min.js' => false, '*jquery-ui.js' => false, '*jquery-ui.min.js' => false, 'jquery-2.1.4.js' => false);
			$this->render('create_hidden_gmc', array('model' => $model, 'modelHiddenDistributerGmcs' => $modelHiddenDistributerGmcs), false, false);
		} else {
			throw new CHttpException(404, 'Page not found.');
		}
	}


	public function actionGetList()
	{
		$_POST  = filter_input_array(INPUT_POST, FILTER_SANITIZE_STRING);
		if (count($_POST) > 0) {
			$model = new MasDistributerType();
			$draw = $_POST['draw'];
			$offset = $_POST['start'];
			$limit = $_POST['length'];
			$columns = array(
				// datatable column index  => database column name
				0 => 'id',
				1 => 'distributer_type',
				2 => 'id',
			);
			$filterColumn = $columns[$_POST['order'][0]['column']];
			$filterOrder = $_POST['order'][0]['dir'];
			$orderBy = $filterColumn . " " . $filterOrder;
			$condition = 't.is_active="Y"';
			if (isset($_POST['search']['value']) && $_POST['search']['value'] != "") {
				$searchString = $_POST['search']['value'];
				$condition .= " and (distributer_type LIKE '%" . $searchString . "%' )";
			}
			$count = $model->count(array('condition' => $condition));
			$model = $model->findAll(array('condition' => $condition, 'limit' => $limit, 'offset' => $offset, 'order' => $orderBy));
			$recordsTotal = $count;
			$recordsFiltered = $count;
			$data['draw'] = $draw;
			$data['recordsTotal'] = $recordsTotal;
			$data['recordsFiltered'] = $recordsFiltered;
			$rowData = array();
			$m = 1;
			foreach ($model as $row) {
				$div = '';
				if (Yii::app()->user->authorised_user == 1 || ((int) Yii::app()->user->havePermissionOn["master_distributer_type_edit"])) {
					$div .=   '<div class="btn-wrap text-center"><button class="btn btn-primary btn-xs" onclick="loadPopupModal(\'distributertype/create&id=' . $row['id'] . '\',\'Edit Distributer Type\',\'xs\')"><i class="fa fa-pencil"></i></button>';
				}

				$div .= '&nbsp;<button class="btn btn-primary btn-xs" title="View" onclick="loadPopupModal(\'distributertype/CreateHiddenGMC&id=' . $row['id'] . '\', \'Add Restricted GMC-' . $row['distributer_type'] . '\', \'lg\')"><i class="fa fa-plus"></i></button>';

				$div .= '&nbsp;<button class="btn btn-primary btn-xs" title="Upload Gmcs" onclick="loadPopupModal(\'hiddengmcuploads/uploadGMC&id=' . $row['id'] . '\', \'Upload Restricted GMC-' . $row['distributer_type'] . '\', \'lg\')"><i class="fa fa-arrow-up"></i></button>';

				$rowData[] = array(
					$m,
					$row['distributer_type'],
					'<div class="btn-wrap text-center">' . $div . '</div>'
				);

				$m++;
			}
			$data['data'] = $rowData;
			echo json_encode($data);
		} else {
			throw new CHttpException(404, 'Page not found.');
		}
	}
	public function actionSave()
	{
		$_POST  = filter_input_array(INPUT_POST, FILTER_SANITIZE_STRING);
		if (count($_POST) > 0) {
			$model = new MasDistributerType();
			if (isset($_POST['MasDistributerType'])) {
				$model->created_by = Yii::app()->user->id;
				$model->created_datetime = date("Y-m-d H:i:s");
				if ((int) @$_POST['MasDistributerType']['id'] > 0) {
					$id = (int) @$_POST['MasDistributerType']['id'];
					$model = $model->findByPk($id);
					$model->updated_by = Yii::app()->user->id;
					$model->updated_datetime = date("Y-m-d H:i:s");
				}

				$model->attributes  = $_POST['MasDistributerType'];
				if ($model->save()) {
					$jsonData['status'] = 'success';
					$jsonData['frm'] = $_POST['MasDistributerType'];
					$jsonData['id'] = $model->id;
					echo CJSON::encode($jsonData);
				} else {
					$error = CActiveForm::validate($model, '', false);
					if ($error != '[]')
						echo $error;
				}
			}
		} else {
			throw new CHttpException(404, 'Page not found.');
		}
	}


	public function actionSavehiddengmc()
	{
		$model = new HiddenDistributerGmcs();
		$validate = true;
		$others = [];
		$modelHiddenDistributerGmcs = [];
		$uniqueProductIds = []; // To track unique product_ids
		if (is_array($_POST['HiddenDistributerGmcs'])) {
			foreach ($_POST['HiddenDistributerGmcs'] as $i => $item) {
				if($item['product_id'] >0){
					$modelHiddenDistributerGmcs[$i]                    = new HiddenDistributerGmcs();
					$modelHiddenDistributerGmcs[$i]->created_by        = Yii::app()->user->id;
					$modelHiddenDistributerGmcs[$i]->created_date_time = date('Y-m-d h:i:s');
					$modelHiddenDistributerGmcs[$i]->attributes        = $item;
					$modelHiddenDistributerGmcs[$i]->product_id        = $item['product_id'];
					$modelHiddenDistributerGmcs[$i]->distributer_type_id            = $_POST['MasDistributerType']['id'];
					$uniqueProductIds[] = $modelHiddenDistributerGmcs[$i]->product_id;
					//$validate                             =  $modelHiddenDistributerGmcs[$i]->validate();
				}
			}
		}



		$countMap = array_count_values($uniqueProductIds);
        foreach ($countMap as $id => $count) {
            if ($count > 1) {
                $validate = false;
                $modelInventory = new Inventory();
                $modelInventory = $modelInventory->findBypk((int)$id)->gmc_code;
                $others[] =  "GMC :- $modelInventory is repeated $count times." . PHP_EOL;
            }
        } 
		if ($validate) {
			HiddenDistributerGmcs::model()->deleteAll('distributer_type_id=:refer_id', array(':refer_id' => $_POST['MasDistributerType']['id']));
			foreach ($modelHiddenDistributerGmcs as $eachModel) {
				$eachModel->save(false);
			}
			$jsonData['status'] = 'success';
			$jsonData['id']     = $_POST['MasDistributerType']['id'];
			echo CJSON::encode($jsonData);
		} else {
			$error1 = array();
			//$error1 = json_decode(CActiveForm::validateTabular($modelHiddenDistributerGmcs, '', false), true);
			$error  = CJSON::encode(array_merge_recursive($error1, $others));
			if ($error != '[]') {
				echo $error;
			}
		}
	}
}
