<?php

class HiddengmcController extends Controller {
    
    public function init() {
        parent::init();
        $this->initAjaxCsrfToken();
    }
 
    // this function will work to post csrf token.
    protected function initAjaxCsrfToken() {
 
        Yii::app()->clientScript->registerScript('AjaxCsrfToken', ' $.ajaxSetup({
                         data: {"' . Yii::app()->request->csrfToken . '": "' . Yii::app()->request->csrfToken . '"},
                         cache:false
                    });', CClientScript::POS_HEAD);
    } 

    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('login', 'error', 'logout'),
                'users' => array('*'),
            ),
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions' => array('Index', 'Create', 'GetList', 'Save', 'Delete','getGmcFromCategory','getModelFromGMC'),
                'expression' => '$user->isMember()',
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    public function actionIndex() {
        $_GET  = filter_input_array(INPUT_GET, FILTER_SANITIZE_STRING);
        if(count($_GET) > 0){
            $this->render('index');
        }
        else{
              throw new CHttpException(404, 'Page not found.');
        }
    }

    // Uncomment the following methods and override them if needed
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
        );
    }

    public function actionGetList() {
        $_POST  = filter_input_array(INPUT_POST, FILTER_SANITIZE_STRING);
        if(count($_POST) > 0){
            $model = new HiddenDistributerGmcs();
            $draw = $_POST['draw'];
            $offset = $_POST['start'];
            $limit = $_POST['length'];
            $distributer_type_id = $_POST['distributer_type_id'];
            $columns = array(
                // datatable column index  => database column name
                0 => 't.id',
                1 => 'category_det.product_category',
                2 => 'gmc_det.gmc_code',
                3 => 'gmc_det.model_no',
                4 => 'dis_det.distributer_type',
            );
            $filterColumn = $columns[$_POST['order'][0]['column']];
            $filterOrder = $_POST['order'][0]['dir'];
            $orderBy = $filterColumn . " " . $filterOrder;
            $condition = '1=1';
            if (isset($_POST['search']['value']) && $_POST['search']['value'] != "") {
                $searchString = $_POST['search']['value'];
                $condition = " (dis_det.distributer_type LIKE '%" . $searchString . "%' OR gmc_det.gmc_code LIKE '%" . $searchString . "%' OR gmc_det.model_no LIKE '%" . $searchString . "%')";
            }
            if($distributer_type_id>0){
                $condition.=' AND distributer_type_id='. $distributer_type_id;
                
            }
            $count = $model->with('gmc_det','dis_det','gmc_det.category_det')->count(array('condition' => $condition));
            $model = $model->with('gmc_det','dis_det','gmc_det.category_det')->findAll(array('condition' => $condition, 'limit' => $limit, 'offset' => $offset, 'order' => $orderBy));
            $recordsTotal = $count;
            $recordsFiltered = $count;
            $data['draw'] = $draw;
            $data['recordsTotal'] = $recordsTotal;
            $data['recordsFiltered'] = $recordsFiltered;
            $rowData = array();
            $m = 1;
            foreach ($model as $row) {
                $div = '';
                if (Yii::app()->user->authorised_user == 1 || ((int) Yii::app()->user->havePermissionOn["master_distributer_edit"])) {
                     $div .=   '<div class="btn-wrap text-center"><button class="btn btn-primary btn-xs" onclick="loadPopupModal(\'hiddengmc/create&id='.$row['id'].'\',\'Edit\',\'lg\')"><i class="fa fa-pencil"></i></button>';
                }
                $rowData[] = array($m,
                    $row['gmc_det']['category_det']['product_category'],
                    $row['gmc_det']['gmc_code'],
                    $row['gmc_det']['model_no'],
                    $row['dis_det']['distributer_type'],
                    '<div class="btn-wrap text-center">' . $div . '</div>');
    
                $m++;
            }
            $data['data'] = $rowData;
            echo json_encode($data);
        }
        else{
              throw new CHttpException(404, 'Page not found.');
        }
    }

    public function actionCreate() {
        $_GET  = filter_input_array(INPUT_GET, FILTER_SANITIZE_STRING);
        if(count($_GET) > 0){
            $model = new HiddenDistributerGmcs();
            $id = (int) Yii::app()->request->getParam('id');
            if ($id > 0) {
                $model = $model->findByPk($id);
            }
            Yii::app()->clientScript->scriptMap = array('*jquery.js' => false, '*jquery.min.js' => false, 'jquery.min.js' => false, '*jquery-ui.js' => false, '*jquery-ui.min.js' => false, 'jquery-2.1.4.js' => false);
            $this->render('create', array('model' => $model), false, false);
        }
        else{
              throw new CHttpException(404, 'Page not found.');
        }
    }

    public function actionSave() {
        $_POST  = filter_input_array(INPUT_POST, FILTER_SANITIZE_STRING);
        if(count($_POST) > 0){
            $model = new HiddenDistributerGmcs();
            if (isset($_POST['HiddenDistributerGmcs'])) {
                    $model->created_by = Yii::app()->user->id;
                    $model->created_date_time = date("Y-m-d H:i:s");
                if ((int) @$_POST['HiddenDistributerGmcs']['id'] > 0) {
                    $id = (int) @$_POST['HiddenDistributerGmcs']['id'];
                    $model = $model->findByPk($id);
                }
                
                $model->attributes          = $_POST['HiddenDistributerGmcs'];
                if ($model->save()) {
                    $jsonData['status'] = 'success';
                    $jsonData['frm'] = $_POST['HiddenDistributerGmcs'];
                    $jsonData['id'] = $model->id;
                    echo CJSON::encode($jsonData);
                } else {
                    $error = CActiveForm::validate($model, '', false);
                    if ($error != '[]')
                        echo $error;
                }
            }
        }
        else{
              throw new CHttpException(404, 'Page not found.');
        }
    }

    /*public function actionDelete() {

        $id = $_POST['id'];
        $model_c = Customer::model()->findAll(array('condition' => 'customer_country = ' . $id . ' '));
        $model_com = Company::model()->findAll(array('condition' => 'shipping_country = ' . $id . ' '));
        if (empty($model_c) && empty($model_com)) {
            $model = new Distributers();
            $model->deleteByPk($id);
            echo "success";
        } else {
            echo "fail";
        }
    }*/
    public function actiongetGmcFromCategory(){
        $cat_id   = (int)Yii::app()->request->getparam("cat_id");
        $model = new HiddenDistributerGmcs();
        $arr_pdts=new Inventory();
        $arr_pdts = $arr_pdts->getActiveCategorywiseGMCs($cat_id);
        $drop = '<li class="col-sm-4">';
        $drop .=CHtml::activeDropdownList($model, 'product_id',$arr_pdts, array('data-label' => 'GMC <span style="color:red">*</span>', 'data-validation' => 'required','empty'=>'-Select-','onchange'=>'getmodelNo(this.value);','data-search'=>'true'));
        $drop .= '</li>';
        $jsondata['dt']= $drop;
        echo CJSON::encode($jsondata);
    }
    public function actiongetModelFromGMC(){
        $product_id     = (int)Yii::app()->request->getparam("product_id");
        $modelInv       = new Inventory();
        $modelInv       = $modelInv->findByPK($product_id);
        $jsondata['model_no'] = $modelInv->model_no;
        echo CJSON::encode($jsondata);
    }


}
