<?php

/**
 * This is the model class for table "{{audit_log}}".
 *
 * The followings are the available columns in table '{{audit_log}}':
 * @property integer $id
 * @property integer $functionality
 * @property string $year
 * @property integer $month
 * @property string $changes
 * @property integer $product_id
 * @property integer $old_value
 * @property integer $new_value
 * @property integer $performed_by
 * @property string $performed_datetime
 */
class AuditLog extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{audit_log}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('functionality, year, month, changes, product_id, old_value, new_value, performed_by, performed_datetime', 'required'),
			array('functionality, month, product_id, old_value, new_value, performed_by', 'numerical', 'integerOnly'=>true),
			array('year', 'length', 'max'=>4),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, functionality, year, month, changes, product_id, old_value, new_value, performed_by, performed_datetime', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		    'product_det' => array(self::BELONGS_TO, 'Inventory', 'product_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'functionality' => 'Functionality',
			'year' => 'Year',
			'month' => 'Month',
			'changes' => 'Changes',
			'product_id' => 'Product',
			'old_value' => 'Old Value',
			'new_value' => 'New Value',
			'performed_by' => 'Performed By',
			'performed_datetime' => 'Performed Datetime',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('functionality',$this->functionality);
		$criteria->compare('year',$this->year,true);
		$criteria->compare('month',$this->month);
		$criteria->compare('changes',$this->changes,true);
		$criteria->compare('product_id',$this->product_id);
		$criteria->compare('old_value',$this->old_value);
		$criteria->compare('new_value',$this->new_value);
		$criteria->compare('performed_by',$this->performed_by);
		$criteria->compare('performed_datetime',$this->performed_datetime,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return AuditLog the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
