<?php

/**
 * This is the model class for table "{{credit_hold_details}}".
 *
 * The followings are the available columns in table '{{credit_hold_details}}':
 * @property integer $id
 * @property integer $credit_hold_id
 * @property integer $product_id
 * @property integer $distributor_id
 * @property string $account_code
 * @property string $distributor
 * @property string $gmc
 * @property string $model
 * @property string $order_date
 * @property string $request_date
 * @property string $order_no
 * @property string $line_no
 * @property string $order_line_no
 * @property string $original_shipment_month
 * @property integer $status
 * @property string $stock_ageing
 * @property string $quantity
 * @property string $unit
 * @property string $amount
 * @property string $currency
 * @property string $amount_in_usd
 * @property string $unit_cbm
 * @property string $total_cbm
 * @property string $pi_no
 * @property string $ex_comment
 * @property string $in_comment
 */
class CreditHoldDetails extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{credit_hold_details}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('credit_hold_id, product_id, distributor_id, account_code, distributor, gmc, model, order_date, request_date, order_no, line_no, order_line_no, original_shipment_month, status', 'required'),
			array('credit_hold_id, product_id,region_id, distributor_id, status', 'numerical', 'integerOnly'=>true),
			array('account_code, distributor, gmc, model, order_no, line_no, order_line_no, original_shipment_month, currency, pi_no', 'length', 'max'=>255),
			array('stock_ageing, quantity, unit, amount, amount_in_usd, unit_cbm, total_cbm', 'length', 'max'=>15),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, credit_hold_id, product_id, distributor_id, account_code, distributor, gmc, model, order_date, request_date, order_no, line_no, order_line_no, original_shipment_month, status, stock_ageing, quantity, unit, amount, currency, amount_in_usd, unit_cbm, total_cbm, pi_no, ex_comment, in_comment', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		    'region_det'=>array(self::BELONGS_TO, 'MasRegion','region_id'),
		    'category_det' => array(self::BELONGS_TO, 'MasProductCategory', 'product_category_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'credit_hold_id' => 'Credit Hold',
			'product_id' => 'Product',
			'distributor_id' => 'Distributor',
			'account_code' => 'Account Code',
			'distributor' => 'Distributor',
			'gmc' => 'Gmc',
			'model' => 'Model',
			'order_date' => 'Order Date',
			'request_date' => 'Request Date',
			'order_no' => 'Order No',
			'line_no' => 'Line No',
			'order_line_no' => 'Order Line No',
			'original_shipment_month' => 'Original Shipment Month',
			'status' => 'Status',
			'stock_ageing' => 'Stock Ageing',
			'quantity' => 'Quantity',
			'unit' => 'Unit',
			'amount' => 'Amount',
			'currency' => 'Currency',
			'amount_in_usd' => 'Amount In Usd',
			'unit_cbm' => 'Unit Cbm',
			'total_cbm' => 'Total Cbm',
			'pi_no' => 'Pi No',
			'ex_comment' => 'Ex Comment',
			'in_comment' => 'In Comment',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('credit_hold_id',$this->credit_hold_id);
		$criteria->compare('product_id',$this->product_id);
		$criteria->compare('distributor_id',$this->distributor_id);
		$criteria->compare('account_code',$this->account_code,true);
		$criteria->compare('distributor',$this->distributor,true);
		$criteria->compare('gmc',$this->gmc,true);
		$criteria->compare('model',$this->model,true);
		$criteria->compare('order_date',$this->order_date,true);
		$criteria->compare('request_date',$this->request_date,true);
		$criteria->compare('order_no',$this->order_no,true);
		$criteria->compare('line_no',$this->line_no,true);
		$criteria->compare('order_line_no',$this->order_line_no,true);
		$criteria->compare('original_shipment_month',$this->original_shipment_month,true);
		$criteria->compare('status',$this->status);
		$criteria->compare('stock_ageing',$this->stock_ageing,true);
		$criteria->compare('quantity',$this->quantity,true);
		$criteria->compare('unit',$this->unit,true);
		$criteria->compare('amount',$this->amount,true);
		$criteria->compare('currency',$this->currency,true);
		$criteria->compare('amount_in_usd',$this->amount_in_usd,true);
		$criteria->compare('unit_cbm',$this->unit_cbm,true);
		$criteria->compare('total_cbm',$this->total_cbm,true);
		$criteria->compare('pi_no',$this->pi_no,true);
		$criteria->compare('ex_comment',$this->ex_comment,true);
		$criteria->compare('in_comment',$this->in_comment,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return CreditHoldDetails the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
