<?php

/**
 * This is the model class for table "{{gmc_goodsin_upload_details}}".
 *
 * The followings are the available columns in table '{{gmc_goodsin_upload_details}}':
 * @property integer $id
 * @property integer $gmc_goodin_upload_id
 * @property integer $category_id
 * @property string $gmc_code
 * @property integer $product_id
 * @property integer $goods_in_month
 * @property string $goods_in_year
 * @property integer $created_by
 * @property string $created_date_time
 * @property integer $updated_by
 * @property string $updated_date_time
 */
class GmcGoodsinUploadDetails extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{gmc_goodsin_upload_details}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('gmc_goodin_upload_id, category_id, gmc_code, product_id, goods_in_month, goods_in_year', 'required'),
			array('gmc_goodin_upload_id, category_id, product_id, goods_in_month, created_by, updated_by', 'numerical', 'integerOnly'=>true),
			array('gmc_code', 'length', 'max'=>255),
			array('goods_in_year', 'length', 'max'=>4,'tooBig'=>'Not in year format'),
			array('goods_in_year', 'numerical', 'min' => 0,'tooSmall' =>'Negative value not accepted'),
			
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, gmc_goodin_upload_id, category_id, gmc_code, product_id, goods_in_month, goods_in_year, created_by, created_date_time, updated_by, updated_date_time', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'gmc_goodin_upload_id' => 'Gmc Goodin Upload',
			'category_id' => 'Category',
			'gmc_code' => 'Gmc Code',
			'product_id' => 'Product',
			'goods_in_month' => 'Goods In Month',
			'goods_in_year' => 'Goods In Year',
			'created_by' => 'Created By',
			'created_date_time' => 'Created Date Time',
			'updated_by' => 'Updated By',
			'updated_date_time' => 'Updated Date Time',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('gmc_goodin_upload_id',$this->gmc_goodin_upload_id);
		$criteria->compare('category_id',$this->category_id);
		$criteria->compare('gmc_code',$this->gmc_code,true);
		$criteria->compare('product_id',$this->product_id);
		$criteria->compare('goods_in_month',$this->goods_in_month);
		$criteria->compare('goods_in_year',$this->goods_in_year,true);
		$criteria->compare('created_by',$this->created_by);
		$criteria->compare('created_date_time',$this->created_date_time,true);
		$criteria->compare('updated_by',$this->updated_by);
		$criteria->compare('updated_date_time',$this->updated_date_time,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return GmcGoodsinUploadDetails the static model class
	 */
	public static function model($className=_CLASS_)
	{
		return parent::model($className);
	}
}
