<?php

/**
 * This is the model class for table "{{hidden_distributer_gmcs}}".
 *
 * The followings are the available columns in table '{{hidden_distributer_gmcs}}':
 * @property integer $id
 * @property integer $distributer_type_id
 * @property integer $product_id
 * @property integer $created_by
 * @property string $created_date_time
 */
class HiddenDistributerGmcs extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{hidden_distributer_gmcs}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('distributer_type_id, product_id', 'required'),
			array('distributer_type_id, product_id, created_by', 'numerical', 'integerOnly'=>true),
			array('distributer_type_id','checkDuplicate'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, distributer_type_id, product_id, created_by, created_date_time', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		    'gmc_det' => array(self::BELONGS_TO, 'Inventory', 'product_id'),
		    'dis_det' => array(self::BELONGS_TO, 'MasDistributerType', 'distributer_type_id'),
		    
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'distributer_type_id' => 'primary key of ymh_distributers',
			'product_id' => 'primary key of ymh_inventory',
			'created_by' => 'Created By',
			'created_date_time' => 'Created Date Time',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('distributer_type_id',$this->distributer_type_id);
		$criteria->compare('product_id',$this->product_id);
		$criteria->compare('created_by',$this->created_by);
		$criteria->compare('created_date_time',$this->created_date_time,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return HiddenDistributerGmcs the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
	
	public function checkDuplicate() {
        if ($this->product_id>0 && $this->distributer_type_id>0) {
            $mode_Hgmc = self::model()->find(['condition'=>'product_id='.(int)$this->product_id.' AND distributer_type_id='.(int)$this->distributer_type_id.' AND id!='.(int)$this->id]);
            if(!empty($mode_Hgmc)){
                $this->addError('distributer_type_id', 'Already Added');
            }
        }
    }
	public static function getHiddenGMCs($distributer_id = 0)
    {
        if ($distributer_id > 0) {
            $modelDistributer = new Distributers();
            $modelDistributer =$modelDistributer->findByPK((int)$distributer_id);
            $distributer_type_id = (int)$modelDistributer->distributer_type;
            
            $models = self::model()->findAll([
                'select' => 'product_id',
                'condition' => 'distributer_type_id=:distributer_type_id',
                'params' => [':distributer_type_id' => $distributer_type_id],
            ]);
            if(!empty($models)){
                return CHtml::listData($models, 'product_id', 'product_id');
            }else{
                return [];
            }
        }
        else
        return [];
    }
}
