<?php

/**
 * This is the model class for table "{{inventory_report_stock_upload_details}}".
 *
 * The followings are the available columns in table '{{inventory_report_stock_upload_details}}':
 * @property integer $id
 * @property integer $inv_report_stock_id
 * @property integer $product_id
 * @property integer $product_category_id
 * @property string $gmc_sub_category
 * @property string $description
 * @property string $gmc
 * @property string $inventory_type
 * @property integer $inv_month
 * @property string $inv_year
 * @property string $inv_category
 * @property integer $created_by
 * @property string $created_date_time
 */
class InventoryReportStockUploadDetails extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{inventory_report_stock_upload_details}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('inv_report_stock_id, product_id, product_category_id, gmc, inv_month, inv_year, inv_category, created_by, created_date_time', 'required'),
			array('inv_report_stock_id, product_id, product_category_id, inv_month, created_by', 'numerical', 'integerOnly'=>true),
			array('gmc_sub_category, gmc', 'length', 'max'=>255),
			array('inventory_type', 'length', 'max'=>1),
			array('inv_category', 'length', 'max'=>200),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, inv_report_stock_id, product_id, product_category_id, gmc_sub_category, description, gmc, inventory_type, inv_month, inv_year, inv_category, created_by, created_date_time', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'inv_report_stock_id' => 'Inv Report Stock',
			'product_id' => 'Product',
			'product_category_id' => 'Product Category',
			'gmc_sub_category' => 'Gmc Sub Category',
			'description' => 'Description',
			'gmc' => 'Gmc',
			'inventory_type' => 'Inventory Type',
			'inv_month' => 'Inv Month',
			'inv_year' => 'Inv Year',
			'inv_category' => 'Inv Category',
			'created_by' => 'Created By',
			'created_date_time' => 'Created Date Time',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('inv_report_stock_id',$this->inv_report_stock_id);
		$criteria->compare('product_id',$this->product_id);
		$criteria->compare('product_category_id',$this->product_category_id);
		$criteria->compare('gmc_sub_category',$this->gmc_sub_category,true);
		$criteria->compare('description',$this->description,true);
		$criteria->compare('gmc',$this->gmc,true);
		$criteria->compare('inventory_type',$this->inventory_type,true);
		$criteria->compare('inv_month',$this->inv_month);
		$criteria->compare('inv_year',$this->inv_year,true);
		$criteria->compare('inv_category',$this->inv_category,true);
		$criteria->compare('created_by',$this->created_by);
		$criteria->compare('created_date_time',$this->created_date_time,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return InventoryReportStockUploadDetails the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
