<?php

/**
 * This is the model class for table "{{mas_product_category}}".
 *
 * The followings are the available columns in table '{{mas_product_category}}':
 * @property integer $id
 * @property string $product_category
 * @property string $is_active
 * @property integer $created_by
 * @property string $created_date_time
 * @property integer $updated_by
 * @property string $updated_date_time
 */
class MasProductCategory extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{mas_product_category}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('product_category,sort_order, is_active', 'required'),
			array('created_by, updated_by,sort_order,report_sort_order','numerical', 'integerOnly'=>true),
			array('product_category, report_name', 'length', 'max'=>255),
			array('product_category', 'unique'),
			array('is_active', 'length', 'max'=>10),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, product_category,sort_order,,report_sort_order,report_name, is_active,
			created_by, created_date_time, updated_by, updated_date_time', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'product_category' => 'Product Category',
			'is_active' => 'Is Active',
			'created_by' => 'Created By',
			'created_date_time' => 'Created Date Time',
			'updated_by' => 'Updated By',
			'updated_date_time' => 'Updated Date Time',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('product_category',$this->product_category,true);
		$criteria->compare('is_active',$this->is_active,true);
		$criteria->compare('created_by',$this->created_by);
		$criteria->compare('created_date_time',$this->created_date_time,true);
		$criteria->compare('updated_by',$this->updated_by);
		$criteria->compare('updated_date_time',$this->updated_date_time,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return MasProductCategory the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
    public static function getProductCategory() {
        $condition = 'is_active =  "Y"';
        $model = self::model()->findAll(array('condition' => $condition, 'order' => 'sort_order ASC'));
        return CHtml::listData($model, 'id', 'product_category');
    }

	public static function getInventoryTypes() {
		$arr_type =['AO'=>'Amount Only','QA'=>'Quantity and Amount'];
		return $arr_type;
    }
	
    /*public static function getmonth_type()
    {
        $arr_month=[];
        $arr_month= array(
            'CM'=>'Current Month',
            'CM-1'=>'Current Month-1',
            'CM-2'=>'Current Month-2',
            'CM-3'=>'Current Month-3',
            'CM-4'=>'Current Month-4',
        );
        return $arr_month;
    }
    public static function getgoodsinmonthyear($year,$month,$mtype){
        $arr =[];
        $no=(int)(explode('-',$mtype)[1]);
        $date =(int)$year.'-'.(int)$month.'-01';
        $new=date('Y-m-d',strtotime(' -'.$no.' months',strtotime($date)));
        $arr['month_taken'] =((int)date('m',strtotime($new)));
        $arr['year_taken'] =((int)date('Y',strtotime($new)));
        return $arr;
    }
    public static function getbacklogmonthyear($year,$month,$mtype){
        $arr =[];
        $no=(int)((explode('-',$mtype)[1]));
        $date =(int)$year.'-'.(int)$month.'-01';
        $new=date('Y-m-d',strtotime(' -'.$no.' months',strtotime($date)));
        $arr['month_taken'] =((int)date('m',strtotime($new)));
        $arr['year_taken'] =((int)date('Y',strtotime($new)));
        return $arr;
    }*/
}
