<?php

/**
 * This is the model class for table "{{mas_settings}}".
 *
 * The followings are the available columns in table '{{mas_settings}}':
 * @property integer $id
 * @property integer $inventory_month
 * @property string $inventory_year
 * @property integer $created_by
 * @property string $created_date_time
 * @property integer $updated_by
 * @property string $updated_date_time
 */
class MasSettings extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{mas_settings}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('inventory_month, inventory_year,currency_rate,eur_rate,lic_percentage,unshipped_month,unshipped_year, created_date_time, updated_by, updated_date_time', 'required'),
			array('inventory_month,unshipped_month, created_by, updated_by', 'numerical', 'integerOnly'=>true),
			array('inventory_year,unshipped_year,lic_percentage', 'length', 'max'=>4),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, inventory_month, inventory_year,eur_rate,unshipped_month,unshipped_year,lic_percentage, created_by, created_date_time, updated_by, updated_date_time', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'inventory_month' => 'Inventory Month',
			'inventory_year' => 'Inventory Year',
			'created_by' => 'Created By',
			'created_date_time' => 'Created Date Time',
			'updated_by' => 'Updated By',
			'updated_date_time' => 'Updated Date Time',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('inventory_month',$this->inventory_month);
		$criteria->compare('inventory_year',$this->inventory_year,true);
		$criteria->compare('created_by',$this->created_by);
		$criteria->compare('created_date_time',$this->created_date_time,true);
		$criteria->compare('updated_by',$this->updated_by);
		$criteria->compare('updated_date_time',$this->updated_date_time,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return MasSettings the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
	public static function AddOneInvMonth(){
	    $modelsettings = MasSettings::model()->find();
	    if((int)$modelsettings->inventory_month==12){
	        $modelsettings->inventory_month=1;
	        $modelsettings->inventory_year=(int)$modelsettings->inventory_year+1;
	    }else{
	        $modelsettings->inventory_month=(int)$modelsettings->inventory_month+1;
	    } 
	    $modelsettings->save(false);
	}
	public static function DeductOneInvMonth(){
	    $modelsettings = MasSettings::model()->find();
	    if((int)$modelsettings->inventory_month==1){
	        $modelsettings->inventory_month=12;
	        $modelsettings->inventory_year=(int)$modelsettings->inventory_year-1;
	    }else{
	        $modelsettings->inventory_month=(int)$modelsettings->inventory_month-1;
	    } 
	    $modelsettings->save(false);
	}
	public static function AddOneUnshippedMonth(){
	    $modelsettings = MasSettings::model()->find();
	    if((int)$modelsettings->unshipped_month==12){
	        $modelsettings->unshipped_month=1;
	        $modelsettings->unshipped_year=(int)$modelsettings->unshipped_year+1;
	    }else{
	        $modelsettings->unshipped_month=(int)$modelsettings->unshipped_month+1;
	    } 
	    $modelsettings->save(false);
	}
	public static function DeductOneUnshippedMonth(){
	    $modelsettings = MasSettings::model()->find();
	    if((int)$modelsettings->unshipped_month==1){
	        $modelsettings->unshipped_month=12;
	        $modelsettings->unshipped_year=(int)$modelsettings->unshipped_year-1;
	    }else{
	        $modelsettings->unshipped_month=(int)$modelsettings->unshipped_month-1;
	    } 
	    $modelsettings->save(false);
	}
	
	public static function GetCurrenctAmt($currency){
	    $modelsettings = MasSettings::model()->find();
        if($currency=='AED'){
            $amount_currency = $modelsettings->currency_rate;
        }else if($currency=='EUR'){
            $amount_currency = $modelsettings->eur_rate;
        }else{
            $amount_currency = 0;
        }
        return $amount_currency;

	}
	
	
	
}
