<?php
/**
 * This is the model class for table "{{order}}".
 *
 * The followings are the available columns in table '{{order}}':
 * @property integer $id
 * @property string $order_date
 * @property integer $distributer_id
 * @property string $month
 * @property string $year
 * @property integer $created_by
 * @property string $created_date_time
 * @property integer $updated_by
 * @property string $updated_date_time
 */
class Order extends CActiveRecord 
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{order}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('order_date, distributer_id, month, year, created_by, created_date_time, updated_by, updated_date_time', 'required'),
			array('distributer_id, created_by, updated_by', 'numerical', 'integerOnly'=>true),
			array('month', 'length', 'max'=>2),
			array('year', 'length', 'max'=>4),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, order_date, distributer_id, month, year, created_by, created_date_time, updated_by, updated_date_time', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
                    'distributer_det' => array(self::BELONGS_TO, 'Distributers', 'distributer_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'order_date' => 'Order Date',
			'distributer_id' => 'Distributer',
			'month' => 'Month',
			'year' => 'Year',
			'created_by' => 'Created By',
			'created_date_time' => 'Created Date Time',
			'updated_by' => 'Updated By',
			'updated_date_time' => 'Updated Date Time',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('order_date',$this->order_date,true);
		$criteria->compare('distributer_id',$this->distributer_id);
		$criteria->compare('month',$this->month,true);
		$criteria->compare('year',$this->year,true);
		$criteria->compare('created_by',$this->created_by);
		$criteria->compare('created_date_time',$this->created_date_time,true);
		$criteria->compare('updated_by',$this->updated_by);
		$criteria->compare('updated_date_time',$this->updated_date_time,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Order the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
        public static function getmonths(){
            $arr_month = array("0"=>"-","1"=>"January", "2"=>"February","3"=> "March", "4"=>"April", "5"=>"May", "6"=>"June",
                "7"=>"July", "8"=>"August", "9"=>"September", "10"=>"October", "11"=>"November", "12"=>"December");
            return $arr_month;
        } 
        public static function getmonthNo($month){
            $arr_month = array("January"=>"1", "February"=>"2","March"=>"3", "April"=>"4", "May"=>"5", "June"=>"6",
                "July"=>"7", "August"=>"8", "September"=>"9", "October"=>"10", "November"=>"11","December"=> "12");
            return $arr_month[$month];
        }
        public static function getyear(){
            $arr_month = array("2018"=>"2018","2019"=>"2019","2020"=>"2020","2021"=>"2021", "2022"=>"2022","2023"=>"2023","2024"=>"2024" ,"2025"=>"2025");
            return $arr_month;
        } 
}?>
