<?php

/**
 * This is the model class for table "{{temp_inventory_price}}".
 *
 * The followings are the available columns in table '{{temp_inventory_price}}':
 * @property integer $id
 * @property integer $upload_id
 * @property integer $product_id
 * @property integer $region_id
 * @property string $cost_price
 * @property string $lic_percentage
 * @property string $price_percentage
 * @property string $price
 * @property string $from_date
 * @property string $to_date
 * @property integer $created_by
 * @property string $created_date_time
 * @property integer $updated_by
 * @property string $updated_date_time
 */
class TempInventoryPrice extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{temp_inventory_price}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('upload_id, product_id, region_id, cost_price, lic_percentage, price_percentage, price, created_by, created_date_time', 'required'),
			array('upload_id, product_id, region_id, created_by, updated_by', 'numerical', 'integerOnly'=>true),
			array('cost_price, lic_percentage, price_percentage', 'length', 'max'=>15),
			array('price', 'length', 'max'=>10),
			array('from_date, to_date', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, upload_id, product_id, region_id, cost_price, lic_percentage, price_percentage, price, from_date, to_date, created_by, created_date_time, updated_by, updated_date_time', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'upload_id' => 'Upload',
			'product_id' => 'Product',
			'region_id' => 'Region',
			'cost_price' => 'Cost Price',
			'lic_percentage' => 'Lic Percentage',
			'price_percentage' => 'Price Percentage',
			'price' => 'Price',
			'from_date' => 'From Date',
			'to_date' => 'To Date',
			'created_by' => 'Created By',
			'created_date_time' => 'Created Date Time',
			'updated_by' => 'Updated By',
			'updated_date_time' => 'Updated Date Time',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('upload_id',$this->upload_id);
		$criteria->compare('product_id',$this->product_id);
		$criteria->compare('region_id',$this->region_id);
		$criteria->compare('cost_price',$this->cost_price,true);
		$criteria->compare('lic_percentage',$this->lic_percentage,true);
		$criteria->compare('price_percentage',$this->price_percentage,true);
		$criteria->compare('price',$this->price,true);
		$criteria->compare('from_date',$this->from_date,true);
		$criteria->compare('to_date',$this->to_date,true);
		$criteria->compare('created_by',$this->created_by);
		$criteria->compare('created_date_time',$this->created_date_time,true);
		$criteria->compare('updated_by',$this->updated_by);
		$criteria->compare('updated_date_time',$this->updated_date_time,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return TempInventoryPrice the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
