<?php

/**
 * This is the model class for table "{{upload_backlog_details}}".
 *
 * The followings are the available columns in table '{{upload_backlog_details}}':
 * @property integer $id
 * @property integer $upload_id
 * @property integer $product_id
 * @property string $gmc_code
 * @property integer $quantity
 * @property integer $created_by
 * @property string $created_date_time
 */
class UploadBacklogDetails extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{upload_backlog_details}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('upload_id, product_id, gmc_code, quantity, created_by, created_date_time', 'required'),
			array('upload_id, product_id, quantity, created_by', 'numerical', 'integerOnly'=>true),
			array('gmc_code', 'length', 'max'=>255),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, upload_id, product_id, gmc_code, quantity, created_by, created_date_time', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		    'product_det' => array(self::BELONGS_TO, 'Inventory', 'product_id'),
		    'parent_det'  => array(self::BELONGS_TO, 'UploadBacklog', 'upload_id')
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'upload_id' => 'Upload',
			'product_id' => 'Product',
			'gmc_code' => 'Gmc Code',
			'quantity' => 'Quantity',
			'created_by' => 'Created By',
			'created_date_time' => 'Created Date Time',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('upload_id',$this->upload_id);
		$criteria->compare('product_id',$this->product_id);
		$criteria->compare('gmc_code',$this->gmc_code,true);
		$criteria->compare('quantity',$this->quantity);
		$criteria->compare('created_by',$this->created_by);
		$criteria->compare('created_date_time',$this->created_date_time,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return UploadBacklogDetails the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
