<?php

/**
 * This is the model class for table "{{upload_sales_details}}".
 *
 * The followings are the available columns in table '{{upload_sales_details}}':
 * @property integer $id
 * @property integer $sales_upload_id
 * @property integer $product_id
 * @property integer $quantity
 * @property integer $distributer_id
 * @property integer $order_id
 * @property integer $order_detail_id
 * @property integer $created_by
 * @property string $created_date_time
 * @property integer $updated_by
 * @property string $updated_date_time
 */
class UploadSalesDetails extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{upload_sales_details}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('sales_upload_id, product_id, quantity, distributer_id, order_id, order_detail_id, created_by, created_date_time, updated_by, updated_date_time', 'required'),
			array('sales_upload_id, product_id, quantity, distributer_id, order_id, order_detail_id, created_by, updated_by', 'numerical', 'integerOnly'=>true),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, sales_upload_id, product_id, quantity, distributer_id, order_id, order_detail_id, created_by, created_date_time, updated_by, updated_date_time', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		    'product_det' => array(self::BELONGS_TO, 'Inventory', 'product_id'),
		    'dis_det'  => array(self::BELONGS_TO, 'Distributers', 'distributer_id'),
		    'parent_det'  => array(self::BELONGS_TO, 'UploadSales', 'sales_upload_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'sales_upload_id' => 'Sales Upload',
			'product_id' => 'Product',
			'quantity' => 'Quantity',
			'distributer_id' => 'Distributer',
			'order_id' => 'Order',
			'order_detail_id' => 'Order Detail',
			'created_by' => 'Created By',
			'created_date_time' => 'Created Date Time',
			'updated_by' => 'Updated By',
			'updated_date_time' => 'Updated Date Time',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('sales_upload_id',$this->sales_upload_id);
		$criteria->compare('product_id',$this->product_id);
		$criteria->compare('quantity',$this->quantity);
		$criteria->compare('distributer_id',$this->distributer_id);
		$criteria->compare('order_id',$this->order_id);
		$criteria->compare('order_detail_id',$this->order_detail_id);
		$criteria->compare('created_by',$this->created_by);
		$criteria->compare('created_date_time',$this->created_date_time,true);
		$criteria->compare('updated_by',$this->updated_by);
		$criteria->compare('updated_date_time',$this->updated_date_time,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return UploadSalesDetails the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
